@@ -34,7 +34,6 @@
 #include "nautilus-link.h"
 #include "nautilus-marshal.h"
 #include "nautilus-metafile.h"
-#include "nautilus-search-uri.h"
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-string.h>
 #include <gtk/gtkmain.h>
@@ -1601,6 +1600,10 @@ nautilus_async_destroying_file (NautilusFile *file)
 		directory->details->link_info_read_state->file = NULL;
 		changed = TRUE;
 	}
+	if (directory->details->extension_info_file == file) {
+		directory->details->extension_info_file = NULL;
+		changed = TRUE;
+	}
 
 	/* Let the directory take care of the rest. */
 	if (changed) {
@@ -1706,44 +1709,6 @@ wants_mime_list (const Request *request)
 {
 	return request->mime_list;
 }
-
-static gboolean
-should_look_for_dot_directory_file (NautilusFile *file)
-{
-	char *uri;
-	guint i;
-
-	const char *schemes [] = {
-		"preferences:",
-		"preferences-all-users:",
-		"all-preferences:",
-		"system-settings:",
-		"server-settings:",
-		"favorites:",
-		"start-here:",
-		"applications:",
-		"applications-all-users:",
-		"all-applications:"
-	};
-
-	uri = file->details->directory->details->uri;
-
-	/* We special-case the file shcme so we won't have
-	 * to go through the list every time
-	 */
-	if (eel_str_has_prefix (uri, "file:")) {
-		return FALSE;
-	}
-
-	for (i = 0; i < G_N_ELEMENTS (schemes); i++) {
-		if (eel_str_has_prefix (uri, schemes[i])) {
-			return TRUE;
-		}
-	}
-
-	return FALSE;
-}
-
 static gboolean
 lacks_link_info (NautilusFile *file)
 {
@@ -1751,9 +1716,6 @@ lacks_link_info (NautilusFile *file)
 	    !file->details->link_info_is_up_to_date) {
 		if (nautilus_file_is_nautilus_link (file)) {
 			return TRUE;
-		} else if (nautilus_file_is_directory (file) &&
-			should_look_for_dot_directory_file (file)) {
-			return TRUE;
 		} else {
 			link_info_done (file->details->directory, file, NULL, NULL, NULL, 0, 0);
 			return FALSE;
@@ -1941,75 +1903,6 @@ mark_all_files_unconfirmed (NautilusDirectory *directory)
 	}
 }
 
-#if GNOME2_HAS_MEDUSA
-
-static gboolean
-should_display_file_name (const char *name,
-			  GnomeVFSDirectoryFilterOptions options)
-{
-	/* Note that the name is URI-encoded, but this should not
-	 * affect the . or the ~.
-	 */
-
-	if ((options & GNOME_VFS_DIRECTORY_FILTER_NODOTFILES) != 0
-	    && nautilus_file_name_matches_hidden_pattern (name)) {
-		return FALSE;
-	}
-
-	if ((options & GNOME_VFS_DIRECTORY_FILTER_NOBACKUPFILES) != 0
-	    && nautilus_file_name_matches_backup_pattern (name)) {
-		return FALSE;
-	}
-	
-	/* Note that we don't bother to check for "." or ".." here, because
-	 * this function is used only for search results, which never include
-	 * those special files. If we later use this function more generally,
-	 * we might have to change this.
-	 */
-	return TRUE;
-}
-
-/* Filter search results based on user preferences. This must be done
- * differently than filtering other files because the search results
- * are encoded: the entire file path is encoded and stored as the file
- * name.
- */
-static gboolean
-filter_search_uri (const GnomeVFSFileInfo *info, gpointer data)
-{
-	GnomeVFSDirectoryFilterOptions options;
-	char *real_file_uri, *filename;
-	gboolean result;
-
-	options = GPOINTER_TO_INT (data);
-	
-	real_file_uri = nautilus_get_target_uri_from_search_result_name (info->name);
-	filename = g_path_get_basename (real_file_uri);
-	result = should_display_file_name (filename, options);	
-	g_free (real_file_uri);
-	g_free (filename);
-
-	return result;
-}
-
-static GnomeVFSDirectoryFilter *
-get_file_count_filter (NautilusDirectory *directory)
-{
-	if (nautilus_is_search_uri (directory->details->uri)) {
-		return gnome_vfs_directory_filter_new_custom
-			(filter_search_uri,
-			 GNOME_VFS_DIRECTORY_FILTER_NEEDS_NAME,
-			 GINT_TO_POINTER (get_filter_options_for_directory_count ()));
-	}
-
-	return gnome_vfs_directory_filter_new
-		(GNOME_VFS_DIRECTORY_FILTER_NONE,
-		 get_filter_options_for_directory_count (),
-		 NULL);
-}
-
-#endif
-
 static void
 read_dot_hidden_file (NautilusDirectory *directory)
 {
@@ -2037,6 +1930,7 @@ read_dot_hidden_file (NautilusDirectory *directory)
 
 	file_info = gnome_vfs_file_info_new ();
 	if (!file_info) {
+		gnome_vfs_uri_unref (dot_hidden_vfs_uri);
 		return;
 	}
 	
@@ -2044,6 +1938,7 @@ read_dot_hidden_file (NautilusDirectory *directory)
 		dot_hidden_vfs_uri,
 		file_info, 
 		GNOME_VFS_FILE_INFO_DEFAULT) != GNOME_VFS_OK) {
+		gnome_vfs_uri_unref (dot_hidden_vfs_uri);
 		gnome_vfs_file_info_unref (file_info);
 		return;
 	}
@@ -2054,6 +1949,7 @@ read_dot_hidden_file (NautilusDirectory *directory)
 	gnome_vfs_file_info_unref (file_info);
 		
 	if (!file_ok) {
+		gnome_vfs_uri_unref (dot_hidden_vfs_uri);
 		return;
 	}
 	
@@ -3084,43 +2980,6 @@ link_info_nautilus_link_read_callback (GnomeVFSResult result,
 	nautilus_directory_unref (directory);
 }
 
-
-static char *
-make_dot_directory_uri (const char *uri)
-{
-	char *dot_directory_uri;
-	GnomeVFSURI *vfs_uri;
-	GnomeVFSURI *dot_dir_vfs_uri;
-
-	/* FIXME: what we really need is a uri_append_file_name call
-	 * that works on strings, so we can avoid the VFS parsing step.
-	 */
-
-	vfs_uri = gnome_vfs_uri_new (uri);
-	if (vfs_uri == NULL) {
-		return NULL;
-	}
-	
-	dot_dir_vfs_uri = gnome_vfs_uri_append_file_name (vfs_uri, ".directory");
-
-	/* This does sync I/O but is allowed here since otherwise nautilus won't start showing the
-	 * directory's contents before all the scheduled calls of "look for .directory file" have been
-	 * finished. 
-	 */
-	if (gnome_vfs_uri_is_local (dot_dir_vfs_uri)) {
-		dot_directory_uri = gnome_vfs_uri_to_string (dot_dir_vfs_uri, GNOME_VFS_URI_HIDE_NONE);
-	}
-	else {
-		dot_directory_uri = NULL;
-	}
-	
-	gnome_vfs_uri_unref (vfs_uri);
-	gnome_vfs_uri_unref (dot_dir_vfs_uri);
-
-	return dot_directory_uri;
-}
-
-
 static void
 link_info_stop (NautilusDirectory *directory)
 {
@@ -3149,8 +3008,8 @@ static void
 link_info_start (NautilusDirectory *directory,
 		 NautilusFile *file)
 {
-	char *uri, *dot_directory_uri = NULL;
-	gboolean nautilus_style_link, is_directory;
+	char *uri;
+	gboolean nautilus_style_link;
 	int file_size;
 	char *file_contents;
 	GnomeVFSResult result;
@@ -3167,16 +3026,10 @@ link_info_start (NautilusDirectory *directory,
 
 	/* Figure out if it is a link. */
 	nautilus_style_link = nautilus_file_is_nautilus_link (file);
-        is_directory = nautilus_file_is_directory (file);
-
 	uri = nautilus_file_get_uri (file);
 	
-	if (is_directory) {
-		dot_directory_uri = make_dot_directory_uri (uri);
-	}
-	
 	/* If it's not a link we are done. If it is, we need to read it. */
-	if (!(nautilus_style_link || (is_directory && dot_directory_uri != NULL) )) {
+	if (!nautilus_style_link) {
 		link_info_done (directory, file, NULL, NULL, NULL, 0, 0);
 	} else if (should_read_link_info_sync (file)) {
 		directory->details->link_info_read_state = g_new0 (LinkInfoReadState, 1);
@@ -3190,27 +3043,17 @@ link_info_start (NautilusDirectory *directory,
 		 */
 	} else {
 		if (!async_job_start (directory, "link info")) {
-			g_free (dot_directory_uri);
 			g_free (uri);
 			return;
 		}
 
 		directory->details->link_info_read_state = g_new0 (LinkInfoReadState, 1);
 		directory->details->link_info_read_state->file = file;
-		if (is_directory) {
-			directory->details->link_info_read_state->handle = eel_read_entire_file_async
-				(dot_directory_uri,
-				 GNOME_VFS_PRIORITY_DEFAULT,
-				 link_info_nautilus_link_read_callback,
-				 directory);
-			g_free (dot_directory_uri);
-		} else {
-			directory->details->link_info_read_state->handle = eel_read_entire_file_async
-				(uri,
-				 GNOME_VFS_PRIORITY_DEFAULT,
-				 link_info_nautilus_link_read_callback,
-				 directory);
-		}
+		directory->details->link_info_read_state->handle = eel_read_entire_file_async
+			(uri,
+			 GNOME_VFS_PRIORITY_DEFAULT,
+			 link_info_nautilus_link_read_callback,
+			 directory);
 	}
 	g_free (uri);
 }
@@ -3219,13 +3062,18 @@ static void
 extension_info_cancel (NautilusDirectory *directory)
 {
 	if (directory->details->extension_info_in_progress != NULL) {
-		nautilus_info_provider_cancel_update 
-			(directory->details->extension_info_provider,
-			 directory->details->extension_info_in_progress);
+		if (directory->details->extension_info_idle) {
+			g_source_remove (directory->details->extension_info_idle);
+		} else {
+			nautilus_info_provider_cancel_update 
+				(directory->details->extension_info_provider,
+				 directory->details->extension_info_in_progress);
+		}
 
 		directory->details->extension_info_in_progress = NULL;
 		directory->details->extension_info_file = NULL;
 		directory->details->extension_info_provider = NULL;
+		directory->details->extension_info_idle = 0;
 
 		async_job_end (directory, "extension info");
 	}
@@ -3290,7 +3138,8 @@ info_provider_idle_callback (gpointer user_data)
 		directory->details->extension_info_file = NULL;
 		directory->details->extension_info_provider = NULL;
 		directory->details->extension_info_in_progress = NULL;
-
+		directory->details->extension_info_idle = 0;
+		
 		finish_info_provider (directory, file, response->provider);
 	}
 
@@ -3311,7 +3160,10 @@ info_provider_callback (NautilusInfoProvider *provider,
 	response->result = result;
 	response->directory = NAUTILUS_DIRECTORY (user_data);
 
-	g_idle_add (info_provider_idle_callback, response);
+	response->directory->details->extension_info_idle =
+		g_idle_add_full (G_PRIORITY_DEFAULT_IDLE,
+				 info_provider_idle_callback, response,
+				 g_free);
 }
 
 static void
