@@ -28,10 +28,6 @@
 
 #include "nautilus-sidebar-title.h"
 
-#include <bonobo/bonobo-property-bag-client.h>
-#include <bonobo/bonobo-ui-util.h>
-#include <bonobo/bonobo-exception.h>
-
 #include <eel/eel-background.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gtk-extensions.h>
@@ -49,7 +45,6 @@
 #include <gtk/gtksignal.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnomeui/gnome-uidefs.h>
-#include <libgnomevfs/gnome-vfs-application-registry.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <libgnomevfs/gnome-vfs-types.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
@@ -64,12 +59,14 @@
 #include <libnautilus-private/nautilus-metadata.h>
 #include <libnautilus-private/nautilus-mime-actions.h>
 #include <libnautilus-private/nautilus-program-choosing.h>
-#include <libnautilus-private/nautilus-sidebar-functions.h>
 #include <libnautilus-private/nautilus-trash-monitor.h>
+#include <libnautilus-private/nautilus-sidebar-provider.h>
+#include <libnautilus-private/nautilus-module.h>
 #include <math.h>
 
 struct NautilusInformationPanelDetails {
 	GtkVBox *container;
+	NautilusWindowInfo *window;
 	NautilusSidebarTitle *title;
 	GtkHBox *button_box_centerer;
 	GtkVBox *button_box;
@@ -88,29 +85,31 @@ struct NautilusInformationPanelDetails {
 /* button assignments */
 #define CONTEXTUAL_MENU_BUTTON 3
 
-static void     nautilus_information_panel_class_init      (GtkObjectClass   *object_klass);
-static void     nautilus_information_panel_init            (GtkObject        *object);
-static gboolean nautilus_information_panel_press_event           (GtkWidget        *widget,
-							GdkEventButton   *event);
-static void     nautilus_information_panel_destroy               (GtkObject        *object);
-static void     nautilus_information_panel_finalize              (GObject          *object);
-static void     nautilus_information_panel_drag_data_received    (GtkWidget        *widget,
-							GdkDragContext   *context,
-							int               x,
-							int               y,
-							GtkSelectionData *selection_data,
-							guint             info,
-							guint             time);
-static void     nautilus_information_panel_read_defaults         (NautilusInformationPanel  *information_panel);
-static void     nautilus_information_panel_style_set             (GtkWidget        *widget,
-							GtkStyle         *previous_style);
-static void     nautilus_information_panel_theme_changed         (gpointer          user_data);
-static void     nautilus_information_panel_confirm_trash_changed (gpointer          user_data);
-static void     nautilus_information_panel_update_appearance     (NautilusInformationPanel  *information_panel);
-static void     nautilus_information_panel_update_buttons        (NautilusInformationPanel  *information_panel);
-static void     add_command_buttons                    (NautilusInformationPanel  *information_panel,
-							GList            *application_list);
-static void     background_metadata_changed_callback   (NautilusInformationPanel  *information_panel);
+static gboolean nautilus_information_panel_press_event           (GtkWidget                    *widget,
+								  GdkEventButton               *event);
+static void     nautilus_information_panel_destroy               (GtkObject                    *object);
+static void     nautilus_information_panel_finalize              (GObject                      *object);
+static void     nautilus_information_panel_drag_data_received    (GtkWidget                    *widget,
+								  GdkDragContext               *context,
+								  int                           x,
+								  int                           y,
+								  GtkSelectionData             *selection_data,
+								  guint                         info,
+								  guint                         time);
+static void     nautilus_information_panel_read_defaults         (NautilusInformationPanel     *information_panel);
+static void     nautilus_information_panel_style_set             (GtkWidget                    *widget,
+								  GtkStyle                     *previous_style);
+static void     nautilus_information_panel_theme_changed         (gpointer                      user_data);
+static void     nautilus_information_panel_confirm_trash_changed (gpointer                      user_data);
+static void     nautilus_information_panel_update_appearance     (NautilusInformationPanel     *information_panel);
+static void     nautilus_information_panel_update_buttons        (NautilusInformationPanel     *information_panel);
+static void     add_command_buttons                              (NautilusInformationPanel     *information_panel,
+								  GList                        *application_list);
+static void     background_metadata_changed_callback             (NautilusInformationPanel     *information_panel);
+static void     nautilus_information_panel_iface_init            (NautilusSidebarIface         *iface);
+static void     nautilus_information_panel_iface_init            (NautilusSidebarIface         *iface);
+static void     sidebar_provider_iface_init                      (NautilusSidebarProviderIface *iface);
+static GType    nautilus_information_panel_provider_get_type     (void);
 
 static gboolean confirm_trash_auto_value = TRUE;
 
@@ -132,7 +131,7 @@ enum {
 	TARGET_GNOME_URI_LIST
 };
 
-static GtkTargetEntry target_table[] = {
+static const GtkTargetEntry target_table[] = {
 	{ "text/uri-list",  0, TARGET_URI_LIST },
 	{ "application/x-color", 0, TARGET_COLOR },
 	{ "property/bgimage", 0, TARGET_BGIMAGE },
@@ -144,27 +143,78 @@ static GtkTargetEntry target_table[] = {
 typedef enum {
 	NO_PART,
 	BACKGROUND_PART,
-	ICON_PART,
+	ICON_PART
 } InformationPanelPart;
 
-EEL_CLASS_BOILERPLATE (NautilusInformationPanel, nautilus_information_panel, EEL_TYPE_BACKGROUND_BOX)
+typedef struct {
+        GObject parent;
+} NautilusInformationPanelProvider;
+
+typedef struct {
+        GObjectClass parent;
+} NautilusInformationPanelProviderClass;
+
+
+G_DEFINE_TYPE_WITH_CODE (NautilusInformationPanel, nautilus_information_panel, EEL_TYPE_BACKGROUND_BOX,
+			 G_IMPLEMENT_INTERFACE (NAUTILUS_TYPE_SIDEBAR,
+						nautilus_information_panel_iface_init));
+/* for EEL_CALL_PARENT */
+#define parent_class nautilus_information_panel_parent_class
+
+G_DEFINE_TYPE_WITH_CODE (NautilusInformationPanelProvider, nautilus_information_panel_provider, G_TYPE_OBJECT,
+			 G_IMPLEMENT_INTERFACE (NAUTILUS_TYPE_SIDEBAR_PROVIDER,
+						sidebar_provider_iface_init));
+
+
+static const char *
+nautilus_information_panel_get_sidebar_id (NautilusSidebar *sidebar)
+{
+	return NAUTILUS_INFORMATION_PANEL_ID;
+}
+
+static char *
+nautilus_information_panel_get_tab_label (NautilusSidebar *sidebar)
+{
+	return g_strdup (_("Information"));
+}
+
+static GdkPixbuf *
+nautilus_information_panel_get_tab_icon (NautilusSidebar *sidebar)
+{
+	return NULL;
+}
+
+static void
+nautilus_information_panel_is_visible_changed (NautilusSidebar *sidebar,
+					       gboolean         is_visible)
+{
+	/* Do nothing */
+}
+
+static void
+nautilus_information_panel_iface_init (NautilusSidebarIface *iface)
+{
+	iface->get_sidebar_id = nautilus_information_panel_get_sidebar_id;
+	iface->get_tab_label = nautilus_information_panel_get_tab_label;
+	iface->get_tab_icon = nautilus_information_panel_get_tab_icon;
+	iface->is_visible_changed = nautilus_information_panel_is_visible_changed;
+}
 
 /* initializing the class object by installing the operations we override */
 static void
-nautilus_information_panel_class_init (GtkObjectClass *object_klass)
+nautilus_information_panel_class_init (NautilusInformationPanelClass *klass)
 {
 	GtkWidgetClass *widget_class;
 	GObjectClass *gobject_class;
+	GtkObjectClass *object_class;
 	
-	NautilusInformationPanelClass *klass;
-
-	widget_class = GTK_WIDGET_CLASS (object_klass);
-	klass = NAUTILUS_INFORMATION_PANEL_CLASS (object_klass);
-	gobject_class = G_OBJECT_CLASS (object_klass);
+	gobject_class = G_OBJECT_CLASS (klass);
+	object_class = GTK_OBJECT_CLASS (klass);
+	widget_class = GTK_WIDGET_CLASS (klass);
 	
 	gobject_class->finalize = nautilus_information_panel_finalize;
 
-	object_klass->destroy = nautilus_information_panel_destroy;
+	object_class->destroy = nautilus_information_panel_destroy;
 	
 	widget_class->drag_data_received  = nautilus_information_panel_drag_data_received;
 	widget_class->button_press_event  = nautilus_information_panel_press_event;
@@ -173,7 +223,7 @@ nautilus_information_panel_class_init (GtkObjectClass *object_klass)
 	/* add the "location changed" signal */
 	signals[LOCATION_CHANGED] = g_signal_new
 		("location_changed",
-		 G_TYPE_FROM_CLASS (object_klass),
+		 G_TYPE_FROM_CLASS (klass),
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET (NautilusInformationPanelClass,
 				    location_changed),
@@ -202,14 +252,12 @@ make_button_box (NautilusInformationPanel *information_panel)
 /* initialize the instance's fields, create the necessary subviews, etc. */
 
 static void
-nautilus_information_panel_init (GtkObject *object)
+nautilus_information_panel_init (NautilusInformationPanel *information_panel)
 {
 	GtkWidget *widget;
 	static gboolean setup_autos = FALSE;
-	NautilusInformationPanel *information_panel;
-	
-	information_panel = NAUTILUS_INFORMATION_PANEL (object);
-	widget = GTK_WIDGET (object);
+
+	widget = GTK_WIDGET (information_panel);
 
 	information_panel->details = g_new0 (NautilusInformationPanelDetails, 1);
 
@@ -356,13 +404,6 @@ nautilus_information_panel_create_context_menu (NautilusInformationPanel *inform
 	return menu;
 }
 
-/* create a new instance */
-NautilusInformationPanel *
-nautilus_information_panel_new (void)
-{
-	return NAUTILUS_INFORMATION_PANEL (gtk_widget_new (nautilus_information_panel_get_type (), NULL));
-}
-
 /* set up the default backgrounds and images */
 static void
 nautilus_information_panel_read_defaults (NautilusInformationPanel *information_panel)
@@ -598,9 +639,9 @@ receive_dropped_keyword (NautilusInformationPanel *information_panel,
 
 static void  
 nautilus_information_panel_drag_data_received (GtkWidget *widget, GdkDragContext *context,
-					 int x, int y,
-					 GtkSelectionData *selection_data,
-					 guint info, guint time)
+					       int x, int y,
+					       GtkSelectionData *selection_data,
+					       guint info, guint time)
 {
 	NautilusInformationPanel *information_panel;
 	EelBackground *background;
@@ -810,7 +851,7 @@ command_button_callback (GtkWidget *button, char *id_str)
 	
 	information_panel = NAUTILUS_INFORMATION_PANEL (g_object_get_data (G_OBJECT (button), "user_data"));
 
-	application = gnome_vfs_application_registry_get_mime_application (id_str);
+	application = gnome_vfs_mime_application_new_from_desktop_id (id_str);
 
 	if (application != NULL) {
 		nautilus_launch_application (application, information_panel->details->file,
@@ -831,44 +872,12 @@ metadata_button_callback (GtkWidget *button, const char *command_str)
 	information_panel = NAUTILUS_INFORMATION_PANEL (g_object_get_data (G_OBJECT (button), "user_data"));
 }
 
-static void
-nautilus_information_panel_chose_application_callback (GnomeVFSMimeApplication *application,
-					     gpointer callback_data)
-{
-	NautilusInformationPanel *information_panel;
-
-	information_panel = NAUTILUS_INFORMATION_PANEL (callback_data);
-
-	if (application != NULL) {
-		nautilus_launch_application
-			(application, 
-			 information_panel->details->file,
-			 nautilus_information_panel_get_window (information_panel));
-	}
-}
-
-static void
-open_with_callback (GtkWidget *button, gpointer ignored)
-{
-	NautilusInformationPanel *information_panel;
-	
-	information_panel = NAUTILUS_INFORMATION_PANEL (g_object_get_data (G_OBJECT (button), "user_data"));
-	
-	g_return_if_fail (information_panel->details->file != NULL);
-
-	nautilus_choose_application_for_file
-		(information_panel->details->file,
-		 GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (information_panel))),
-		 nautilus_information_panel_chose_application_callback,
-		 information_panel);
-}
-
 /* utility routine that allocates the command buttons from the command list */
 
 static void
 add_command_buttons (NautilusInformationPanel *information_panel, GList *application_list)
 {
-	char *id_string, *temp_str, *file_path;
+	char *id_string, *temp_str;
 	GList *p;
 	GtkWidget *temp_button;
 	GnomeVFSMimeApplication *application;
@@ -887,16 +896,7 @@ add_command_buttons (NautilusInformationPanel *information_panel, GList *applica
 				    FALSE, FALSE, 
 				    0);
 
-		/* Get the local path, if there is one */
-		file_path = gnome_vfs_get_local_path_from_uri (information_panel->details->uri);
-		if (file_path == NULL) {
-			file_path = g_strdup (information_panel->details->uri);
-		} 
-
-		temp_str = g_shell_quote (file_path);		
-		id_string = eel_str_replace_substring (application->id, "%s", temp_str); 		
-		g_free (file_path);
-		g_free (temp_str);
+		id_string = g_strdup (gnome_vfs_mime_application_get_desktop_id (application));
 
 		eel_gtk_signal_connect_free_data 
 			(GTK_OBJECT (temp_button), "clicked",
@@ -906,15 +906,6 @@ add_command_buttons (NautilusInformationPanel *information_panel, GList *applica
 		
 		gtk_widget_show (temp_button);
 	}
-
-	/* Catch-all button after all the others. */
-	temp_button = gtk_button_new_with_label (_("Open with..."));
-	g_signal_connect (temp_button, "clicked",
-			  G_CALLBACK (open_with_callback), NULL);
-	g_object_set_data (G_OBJECT (temp_button), "user_data", information_panel);
-	gtk_widget_show (temp_button);
-	gtk_box_pack_start (GTK_BOX (information_panel->details->button_box),
-			    temp_button, FALSE, FALSE, 0);
 }
 
 /* utility to construct command buttons for the information_panel from the passed in metadata string */
@@ -1062,14 +1053,11 @@ nautilus_information_panel_update_buttons (NautilusInformationPanel *information
 		g_signal_connect (temp_button, "clicked",
 				  G_CALLBACK (burn_cd_callback), NULL);
 	}
-	
-	/* Make buttons for each item in short list + "Open with..." catchall,
-	 * unless there aren't any applications at all in complete list. 
-	 */
 
+	/* Make buttons for each application */
 	if (nautilus_mime_has_any_applications_for_file (information_panel->details->file)) {
 		short_application_list = 
-			nautilus_mime_get_short_list_applications_for_file (information_panel->details->file);
+			nautilus_mime_get_applications_for_file (information_panel->details->file);
 		add_command_buttons (information_panel, short_application_list);
 		gnome_vfs_mime_application_list_free (short_application_list);
 	}
@@ -1158,10 +1146,10 @@ background_metadata_changed_callback (NautilusInformationPanel *information_pane
 
 /* here is the key routine that populates the information_panel with the appropriate information when the uri changes */
 
-void
+static void
 nautilus_information_panel_set_uri (NautilusInformationPanel *information_panel, 
-			  const char* new_uri,
-			  const char* initial_title)
+				    const char* new_uri,
+				    const char* initial_title)
 {       
 	NautilusFile *file;
 	NautilusFileAttributes attributes;
@@ -1207,10 +1195,12 @@ nautilus_information_panel_set_uri (NautilusInformationPanel *information_panel,
 					 initial_title);
 }
 
-void
-nautilus_information_panel_set_title (NautilusInformationPanel *information_panel, const char* new_title)
+static void
+title_changed_callback (NautilusWindowInfo *window,
+			char               *new_title,
+			NautilusInformationPanel *panel)
 {       
-	nautilus_sidebar_title_set_text (information_panel->details->title,
+	nautilus_sidebar_title_set_text (panel->details->title,
 					 new_title);
 }
 
@@ -1224,3 +1214,79 @@ nautilus_information_panel_style_set (GtkWidget *widget, GtkStyle *previous_styl
 
 	nautilus_information_panel_theme_changed (information_panel);
 }
+
+static void
+loading_uri_callback (NautilusWindowInfo *window,
+		      char               *uri,
+		      NautilusInformationPanel *panel)
+{
+	char *title;
+
+	title = nautilus_window_info_get_title (window);
+	nautilus_information_panel_set_uri (panel, 
+					    uri,
+					    title);
+	g_free (title);
+}
+
+static void
+nautilus_information_panel_set_parent_window (NautilusInformationPanel *panel,
+					      NautilusWindowInfo *window)
+{
+	char *title, *location;
+
+	panel->details->window = window;
+	
+	g_signal_connect_object (window, "loading_uri",
+				 G_CALLBACK (loading_uri_callback), panel, 0);
+	g_signal_connect_object (window, "title_changed",
+				 G_CALLBACK (title_changed_callback), panel, 0);
+	
+	title = nautilus_window_info_get_title (window);
+	location = nautilus_window_info_get_current_location (window);
+	nautilus_information_panel_set_uri (panel, 
+					    location,
+					    title);
+	g_free (location);
+	g_free (title);
+
+
+}
+
+static NautilusSidebar *
+nautilus_information_panel_create (NautilusSidebarProvider *provider,
+				   NautilusWindowInfo *window)
+{
+	NautilusInformationPanel *panel;
+	
+	panel = g_object_new (nautilus_information_panel_get_type (), NULL);
+	nautilus_information_panel_set_parent_window (panel, window);
+	g_object_ref (panel);
+	gtk_object_sink (GTK_OBJECT (panel));
+
+	return NAUTILUS_SIDEBAR (panel);
+}
+
+static void 
+sidebar_provider_iface_init (NautilusSidebarProviderIface *iface)
+{
+	iface->create = nautilus_information_panel_create;
+}
+
+static void
+nautilus_information_panel_provider_init (NautilusInformationPanelProvider *sidebar)
+{
+}
+
+static void
+nautilus_information_panel_provider_class_init (NautilusInformationPanelProviderClass *class)
+{
+}
+
+
+void
+nautilus_information_panel_register (void)
+{
+        nautilus_module_add_type (nautilus_information_panel_provider_get_type ());
+}
+
