@@ -274,8 +274,9 @@ nautilus_window_go_up (NautilusWindow *window, gboolean close_behind)
 	eel_g_list_free_deep (selection);
 }
 
-void
-nautilus_window_allow_up (NautilusWindow *window, gboolean allow)
+static void
+real_set_allow_up (NautilusWindow *window,
+		   gboolean        allow)
 {
 	GtkAction *action;
 	
@@ -289,6 +290,13 @@ nautilus_window_allow_up (NautilusWindow *window, gboolean allow)
 	gtk_action_set_sensitive (action, allow);
 }
 
+void
+nautilus_window_allow_up (NautilusWindow *window, gboolean allow)
+{
+	EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
+			 set_allow_up, (window, allow));
+}
+
 void
 nautilus_window_allow_stop (NautilusWindow *window, gboolean allow)
 {
@@ -558,6 +566,26 @@ nautilus_window_finalize (GObject *object)
 	G_OBJECT_CLASS (nautilus_window_parent_class)->finalize (object);
 }
 
+void
+nautilus_window_show_window (NautilusWindow *window)
+{
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+
+	EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
+			 show_window, (window));
+
+	nautilus_window_update_title (window);
+	nautilus_window_update_icon (window);
+
+	gtk_widget_show (GTK_WIDGET (window));
+
+	if (window->details->viewed_file) {
+		if (NAUTILUS_IS_SPATIAL_WINDOW (window)) {
+			nautilus_file_set_has_open_window (window->details->viewed_file, TRUE);
+		}
+	}
+}
+
 void
 nautilus_window_close (NautilusWindow *window)
 {
@@ -642,23 +670,17 @@ add_view_as_menu_item (NautilusWindow *window,
 		       int index, /* extra_viewer is always index 0 */
 		       guint merge_id)
 {
-	char *tip;
 	const NautilusViewInfo *info;
-	char *label;
 	GtkRadioAction *action;
 	char *action_name;
 	ActivateViewData *data;
 
 	info = nautilus_view_factory_lookup (identifier);
-
-	label = g_strdup_printf (_("View as %s"), _(info->label_with_mnemonic));
-	tip = g_strdup_printf (_("Display this location with \"%s\""),
-			       _(info->label));
 	
 	action_name = g_strdup_printf ("view_as_%d", index);
 	action = gtk_radio_action_new (action_name,
-				       label,
-				       tip,
+				       _(info->view_as_label_with_mnemonic),
+				       _(info->display_location_label),
 				       NULL,
 				       0);
 
@@ -670,9 +692,6 @@ add_view_as_menu_item (NautilusWindow *window,
 		   as it can get deleted/changed later */
 		window->details->view_as_radio_action = action;
 	}
-	
-	g_free (label);
-	g_free (tip);
 
 	data = g_new (ActivateViewData, 1);
 	data->window = window;
@@ -1186,9 +1205,6 @@ nautilus_window_set_viewed_file (NautilusWindow *window,
 	}
 
 	if (file != NULL) {
-		if (NAUTILUS_IS_SPATIAL_WINDOW (window)) {
-			nautilus_file_set_has_open_window (file, TRUE);
-		}
 		attributes = NAUTILUS_FILE_ATTRIBUTE_DISPLAY_NAME | NAUTILUS_FILE_ATTRIBUTE_SLOW_MIME_TYPE;
 		nautilus_file_monitor_add (file, window, attributes);
 	}
@@ -1407,6 +1423,7 @@ nautilus_window_info_iface_init (NautilusWindowInfoIface *iface)
 	iface->report_selection_changed = nautilus_window_report_selection_changed;
 	iface->report_view_failed = nautilus_window_report_view_failed;
 	iface->open_location = nautilus_window_open_location_full;
+	iface->show_window = nautilus_window_show_window;
 	iface->close_window = nautilus_window_close;
 	iface->set_status = nautilus_window_set_status;
 	iface->get_window_type = nautilus_window_get_window_type;
@@ -1436,12 +1453,13 @@ nautilus_window_class_init (NautilusWindowClass *class)
 	class->set_title = real_set_title;
 	class->set_content_view_widget = real_set_content_view_widget;
 	class->load_view_as_menu = real_load_view_as_menu;
+	class->set_allow_up = real_set_allow_up;
 
 	g_object_class_install_property (G_OBJECT_CLASS (class),
 					 ARG_APP,
 					 g_param_spec_object ("app",
-							      _("Application"),
-							      _("The NautilusApplication associated with this window."),
+							      "Application",
+							      "The NautilusApplication associated with this window.",
 							      NAUTILUS_TYPE_APPLICATION,
 							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 	
